@@ -97,8 +97,16 @@
 /*                                                                          */
 
 
+#ifdef __linux__
+/* string.h: strdup */
+#undef _XOPEN_SOURCE
+#define _XOPEN_SOURCE 600
+#define _POSIX_C_SOURCE 2
+#endif
+
 #include <string.h>
 #include <stdlib.h>
+#include <stdio.h>
 
 #include <pargs.h>
 #include "pfile.h"
@@ -122,7 +130,7 @@ int t_valu;
  */
 static char nstr[1];
 
-#line 126 "cxcparam/iarg_yac.c" /* yacc.c:337  */
+#line 134 "cxcparam/iarg_yac.c" /* yacc.c:337  */
 # ifndef YY_NULLPTR
 #  if defined __cplusplus
 #   if 201103L <= __cplusplus
@@ -177,12 +185,12 @@ extern int iarg_debug;
 
 union YYSTYPE
 {
-#line 55 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:352  */
+#line 63 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:352  */
 
 	ParamList	*plist;
 	char		*stri;
 
-#line 186 "cxcparam/iarg_yac.c" /* yacc.c:352  */
+#line 194 "cxcparam/iarg_yac.c" /* yacc.c:352  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -486,8 +494,8 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    66,    66,    71,    83,    94,   102,   110,   118,   126,
-     135
+       0,    74,    74,    79,    91,   102,   110,   118,   126,   134,
+     143
 };
 #endif
 
@@ -1269,13 +1277,13 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 67 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
+#line 75 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
     { result = (yyval.plist);	}
-#line 1275 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1283 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
     break;
 
   case 3:
-#line 72 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
+#line 80 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
     { 
 		  if ( reference == 0 ) {
 			parerr = PARNOREFR;
@@ -1287,11 +1295,11 @@ yyreduce:
 
 		  if ( (yyval.plist) == NULL ) return 1;
 		}
-#line 1291 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1299 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
     break;
 
   case 4:
-#line 84 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
+#line 92 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
     { 
 		  if ( reference == 0 ) {
 			parerr = PARNOREFR;
@@ -1302,11 +1310,11 @@ yyreduce:
 		   , ParamPositional(reference, position++, (yyvsp[0].stri)));
 		  if ( (yyval.plist) == 0 ) return 1;
 		}
-#line 1306 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1314 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
     break;
 
   case 5:
-#line 95 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
+#line 103 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
     { 		int mode;
 		  mode = QMODE;
 		  (yyval.plist) = PListAdd(NULL
@@ -1314,11 +1322,11 @@ yyreduce:
 				 , StringType, &mode, strdup(nstr), NULL));
 		  if ( (yyval.plist) == 0 ) return 1;
 		}
-#line 1318 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1326 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
     break;
 
   case 6:
-#line 103 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
+#line 111 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
     {  		int mode;
 		  mode = QMODE;
 		  (yyval.plist) = PListAdd((yyvsp[-2].plist)
@@ -1326,11 +1334,11 @@ yyreduce:
 				 , StringType, &mode, strdup(nstr), NULL));
 		  if ( (yyval.plist) == 0 ) return 1;
 		}
-#line 1330 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1338 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
     break;
 
   case 7:
-#line 111 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
+#line 119 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
     {  		int mode;
 		  mode = LMODE;
 		  (yyval.plist) = PListAdd(NULL
@@ -1338,11 +1346,11 @@ yyreduce:
 				 , StringType, &mode, (yyvsp[0].stri), NULL));
 		  if ( (yyval.plist) == 0 ) return 1;
 		}
-#line 1342 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1350 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
     break;
 
   case 8:
-#line 119 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
+#line 127 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
     {  		int mode;
 		  mode = LMODE;
 		  (yyval.plist) = PListAdd((yyvsp[-2].plist)
@@ -1350,11 +1358,11 @@ yyreduce:
 				 , StringType, &mode, (yyvsp[0].stri), NULL));
 		  if ( (yyval.plist) == NULL ) return 1;
 		}
-#line 1354 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1362 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
     break;
 
   case 9:
-#line 127 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
+#line 135 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
     {  		int mode;
 		  mode = LMODE;
 
@@ -1363,11 +1371,11 @@ yyreduce:
 				 , StringType, &mode, (yyvsp[0].stri), NULL));
 		  if ( (yyval.plist) == 0 ) return 1;
 		}
-#line 1367 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1375 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
     break;
 
   case 10:
-#line 136 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
+#line 144 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1652  */
     {  		int mode;
 		  mode = LMODE;
 		  (yyval.plist) = PListAdd((yyvsp[-3].plist)
@@ -1375,11 +1383,11 @@ yyreduce:
 				  , StringType, &mode, (yyvsp[0].stri), NULL));
 		  if ( (yyval.plist) == 0 ) return 1;
 		}
-#line 1379 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1387 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
     break;
 
 
-#line 1383 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
+#line 1391 "cxcparam/iarg_yac.c" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1610,7 +1618,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 144 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1918  */
+#line 152 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/iarg.y" /* yacc.c:1918  */
 
 
 ParamList *IRAFParArgs(ParamList *plist, char *argv[], int argc )
