@@ -99,6 +99,11 @@
 /* ipar.y
 **/
 
+#ifdef __linux__
+/* stdio.h: fileno */
+#define _POSIX_C_SOURCE 2
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <string.h>
@@ -129,19 +134,11 @@ static ParamList *result;
 
 extern int	ipar_lineno;
 
-/* GNU cc prior to version 10 defaults to -fcommon. After 10 it
-   defaults to -fno-common, so don't both declare ipar_lineno both extern and
-   define it here.
- */
-#if defined( __GNUC__ ) && ! defined( __APPLE_CC__ ) && __GNUC__ < 10           
-int	ipar_lineno;
-#endif /* __GNUC__ */
-
 #define YYDEBUG 1
 #define YYINITDEPTH 256
 #define YYMAXDEPTH  257
 
-#line 145 "cxcparam/ipar_yac.c" /* yacc.c:337  */
+#line 142 "cxcparam/ipar_yac.c" /* yacc.c:337  */
 # ifndef YY_NULLPTR
 #  if defined __cplusplus
 #   if 201103L <= __cplusplus
@@ -198,13 +195,13 @@ extern int ipar_debug;
 
 union YYSTYPE
 {
-#line 68 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:352  */
+#line 65 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:352  */
 
 	ParamList	*plist;
 	Parameter	*param;
 	char		*stri;
 
-#line 208 "cxcparam/ipar_yac.c" /* yacc.c:352  */
+#line 205 "cxcparam/ipar_yac.c" /* yacc.c:352  */
 };
 
 typedef union YYSTYPE YYSTYPE;
@@ -508,9 +505,9 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    93,    93,    97,   104,   112,   113,   114,   115,   123,
-     131,   139,   138,   154,   156,   161,   162,   166,   172,   181,
-     183
+       0,    90,    90,    94,   101,   109,   110,   111,   112,   120,
+     128,   136,   135,   151,   153,   158,   159,   163,   169,   178,
+     180
 };
 #endif
 
@@ -1305,44 +1302,44 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 94 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 91 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { result = (yyvsp[0].plist);			}
-#line 1311 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1308 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 3:
-#line 98 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 95 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { if ( (yyvsp[0].param) && ((yyvsp[0].param)->pvalue.value==NULL) )
 			VNewValue(&(yyvsp[0].param)->pvalue, "", StringType);
 
 		  if ( (yyvsp[0].param) != NULL )
 			(yyval.plist) = PListAdd(NULL, (yyvsp[0].param));
 		}
-#line 1322 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1319 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 4:
-#line 105 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 102 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { if ( (yyvsp[0].param) && ((yyvsp[0].param)->pvalue.value==NULL) )
 			VNewValue(&(yyvsp[0].param)->pvalue, "", StringType);
 
 		  if ( (yyvsp[0].param) != NULL )
 			(yyval.plist) = PListAdd((yyvsp[-1].plist), (yyvsp[0].param));	}
-#line 1332 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1329 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 8:
-#line 116 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 113 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { 		int	mode = 0;
 		  (yyval.param) = ParamCreate(str_duplicate("")
 				, CommentType 
 				, &mode, str_duplicate(""), NULL); 
 		}
-#line 1342 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1339 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 9:
-#line 124 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 121 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { 		int	mode;
 		  (yyval.param) = ParamCreate((yyvsp[-8].stri)
 				, String2Type((yyvsp[-6].stri))
@@ -1350,20 +1347,20 @@ yyreduce:
 			if ( (yyvsp[-6].stri) != NULL ) free((yyvsp[-6].stri));
 			if ( (yyvsp[-4].stri) != NULL ) free((yyvsp[-4].stri));
 		}
-#line 1354 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1351 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 10:
-#line 132 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 129 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { 		int	mode;
 		  (yyval.param) = ParamCreate((yyvsp[-7].stri)
 				, String2Type((yyvsp[-5].stri))
 				, String2Mode((yyvsp[-3].stri), &mode), NULL, (yyvsp[-1].param)); }
-#line 1363 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1360 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 11:
-#line 139 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 136 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { 		int	mode = 0;
 		  (yyval.param) = ParamCreate((yyvsp[-8].stri)
 				, String2Type((yyvsp[-6].stri))
@@ -1373,78 +1370,78 @@ yyreduce:
 
 		  ipar_begin(LINE);
 		}
-#line 1377 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1374 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 12:
-#line 149 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 146 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { (yyval.param) = ParamStruct((yyvsp[-1].param), (yyvsp[0].stri));
 		  ipar_begin(NAME);
 		}
-#line 1385 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1382 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 13:
-#line 155 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 152 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { (yyval.stri) = (yyvsp[-1].stri);		}
-#line 1391 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1388 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 14:
-#line 157 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 154 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { (yyval.stri) = NULL;		}
-#line 1397 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1394 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 15:
-#line 161 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 158 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { (yyval.param) = NULL;					}
-#line 1403 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1400 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 16:
-#line 163 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 160 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { (yyval.param) = NULL;
 		  if ( (yyvsp[0].stri) ) ParamMin(NULL, StringType, (yyvsp[0].stri));
 		}
-#line 1411 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1408 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 17:
-#line 167 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 164 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { 
 		  (yyval.param) = NULL;
 		  if ( (yyvsp[-1].stri) ) (yyval.param) = ParamMin(NULL, StringType, (yyvsp[-1].stri));
 		  if ( (yyvsp[0].stri) ) (yyval.param) = ParamMax(  (yyval.param), StringType, (yyvsp[0].stri));
 		}
-#line 1421 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1418 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 18:
-#line 173 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 170 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     {
 		  (yyval.param) = NULL;
 		  if ( (yyvsp[-2].stri) ) (yyval.param) = ParamMin( NULL, StringType, (yyvsp[-2].stri));
 		  if ( (yyvsp[-1].stri) ) (yyval.param) = ParamMax(   (yyval.param), StringType, (yyvsp[-1].stri));
 		  if ( (yyvsp[0].stri) ) (yyval.param) = ParamPrompt((yyval.param), (yyvsp[0].stri));
 		}
-#line 1432 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1429 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 19:
-#line 182 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 179 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { (yyval.stri) = NULL;					}
-#line 1438 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1435 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
   case 20:
-#line 184 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
+#line 181 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1652  */
     { (yyval.stri) = (yyvsp[0].stri);					}
-#line 1444 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1441 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
     break;
 
 
-#line 1448 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
+#line 1445 "cxcparam/ipar_yac.c" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1675,7 +1672,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 186 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1918  */
+#line 183 "/data/pelf1/dj/hd0/axaf/src/cxcparam/cxcparam/ipar.y" /* yacc.c:1918  */
 
 
 
