@@ -180,11 +180,11 @@ c_minmax_check (ParamFile pf)
 
 
 paramfile
-c_paramopen (filename, argv, argc, filemode)
-     const char *filename;
-     char *argv[];
-     int argc;
-     const char *filemode;
+c_paramopen (
+             const char *filename,
+             char *argv[],
+             int argc,
+             const char *filemode )
 {
   int i;
   ParamFile pf;
@@ -507,9 +507,8 @@ c_paramopen (filename, argv, argc, filemode)
   return pf;
 }
 
-void
-c_paramunlock (pf)
-     ParamFile pf;
+void 
+c_paramunlock (ParamFile pf)
 {
   if (pf == NULL)
     return;
@@ -518,9 +517,8 @@ c_paramunlock (pf)
 }
 
 
-void
-c_paramclose (pf)
-     ParamFile pf;
+void 
+c_paramclose (ParamFile pf)
 {
 
   if (pf == NULL)
@@ -678,10 +676,7 @@ c_paramwrite (ParamFile pf)
 
 
 ParamList *
-ParamFileArgs (plist, argv, argc)
-     ParamList *plist;
-     char *argv[];
-     int argc;
+ParamFileArgs (ParamList *plist, char *argv[], int argc)
 {
   return IRAFParArgs (plist, argv, argc);
 }
